==> python-gearbox-0.1.1b.dev.zip: python-gearbox-0.1.1b.dev/gearbox/export/export.py <==
# coding=utf-8
import os
from math import radians, tan, cos

from jinja2 import Environment, FileSystemLoader

import gearbox
from gearbox.libs.gearprofile import GearExport
from gearbox.libs.maths import rotate, involute, arcinvolute


class ExportGear(object):
    """

    :param gear:
    """

    def __init__(self, gear):
        template_path = os.path.join(gearbox.__path__[0], 'export', 'templates')
        self.env = Environment(loader=FileSystemLoader(template_path))

        self.gear = gear
        z = gear.z
        m = gear.m
        beta = gear.beta
        alpha = gear.alpha
        x = gear.x
        rho_f = gear.profile.rho_fp
        d_s = gear.shaft_diameter
        c = gear.profile.c
        b = gear.b

        gear_data = {'m_n': m, 'z': z, 'beta': beta, 'alpha_n': alpha, 'x': x, 'rho_f': rho_f, 'd_s': d_s, 'c': c,
                     'b': b}
        self.gear.export_data = GearExport(gear_data)

    def matlab_comsol(self, output_folder='', model_name='model', type='2D'):
        """

        :param model_name:
        :param output_folder:
        :param type:
        """

        if type is '2D':
            template = self.env.get_template('comsol_gear.template')
        elif type is '3D':
            template = self.env.get_template('comsol_gear3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        model_name = model_name.replace(' ', '_')
        output_folder = output_folder.replace('/', '\\')

        output_from_parsed_template = template.render(gear=self.gear.export_data.gear, model_name=model_name,
                                                      model_path=output_folder)

        with open(output_folder + '/' + model_name + '.m', "wb") as fh:
            fh.write(output_from_parsed_template)

    def abaqus(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        :raise ValueError:
        """

        if type is '2D':
            template = self.env.get_template('abaqus_gear.template')
        elif type is '3D':
            template = self.env.get_template('abaqus_gear3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        model_name = model_name.replace(' ', '_')
        output_folder = output_folder.replace('/', '\\')

        output_from_parsed_template = template.render(gear=self.gear.export_data.gear, model_name=model_name,
                                                      model_path=output_folder)

        with open(output_folder + '/' + model_name + '.py', "wb") as fh:
            fh.write(output_from_parsed_template)

    def ansys(self):
        pass


class ExportPair(object):
    """

    :param pair:
    """

    def __init__(self, pair):
        template_path = os.path.join(gearbox.__path__[0], 'export', 'templates')
        self.env = Environment(loader=FileSystemLoader(template_path))

        self.pinion = ExportGear(pair[0]).gear.export_data.gear
        self.wheel = ExportGear(pair[1]).gear.export_data.gear

        shaft = [[0, (self.wheel.data['d_s'] / 2)], rotate([[0, self.wheel.data['d_s'] / 2]], 0.5 * (
            (self.wheel.data['d_s'] / self.wheel.data['z']) * 360 / self.wheel.data['d_s']))[0]]

        coords = rotate(self.wheel.formcoords, 180)

        aw = self.__aw()

        self.wheel.shaftcoords = [[coord[0], coord[1] + aw] for coord in rotate(shaft, 180)]
        self.wheel.formcoords = [[coord[0], coord[1] + aw] for coord in coords]

        self.pinion.rotate_x = 0
        self.pinion.rotate_y = 0

        self.wheel.rotate_x = 0
        self.wheel.rotate_y = aw

    def matlab_comsol(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        """

        if type is '2D':
            template = self.env.get_template('comsol_pair.template')
        elif type is '3D':
            template = self.env.get_template('comsol_pair3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        pair = [self.pinion, self.wheel]

        model_name = model_name.replace(' ', '_')

        output_from_parsed_template = template.render(pair=pair, model_name=model_name, model_path=output_folder)

        with open(output_folder + '/' + model_name + '.m', "wb") as fh:
            fh.write(output_from_parsed_template)

    def abaqus(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        """

        if type is '2D':
            template = self.env.get_template('abaqus_pair.template')
        elif type is '3D':
            template = self.env.get_template('abaqus_pair3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        pair = [self.pinion, self.wheel]

        model_name = model_name.replace(' ', '_')

        output_from_parsed_template = template.render(pair=pair, model_name=model_name, model_path=output_folder)

        with open(output_folder + '/' + model_name + '.py', "wb") as fh:
            fh.write(output_from_parsed_template)

    def __aw(self):
        inv = involute(self.pinion.data['alpha_t']) + 2 * (self.pinion.data['x'] + self.wheel.data['x']) / (
            self.pinion.data['z'] + self.wheel.data['z']) * tan(
            radians(self.pinion.data['alpha_n']))
        alpha_wt = arcinvolute(inv)
        a = ((self.pinion.data['z'] + self.wheel.data['z']) * self.pinion.data['m_n']) / (
            2 * cos(radians(self.pinion.data['beta'])))
        aw = a * cos(radians(self.pinion.data['alpha_n'])) / cos(radians(alpha_wt))
        return aw

==> python-gearbox-0.1.2.a.dev.zip: python-gearbox-0.1.2.a.dev/gearbox/export/export.py <==
# coding=utf-8
import os
from math import radians, tan, cos

from jinja2 import Environment, FileSystemLoader

import gearbox
from gearbox.libs.gearprofile import GearExport
from gearbox.libs.maths import rotate, involute, arcinvolute


class ExportGear(object):
    """

    :param gear:
    """

    def __init__(self, gear):
        template_path = os.path.join(gearbox.__path__[0], 'export', 'templates')
        self.env = Environment(loader=FileSystemLoader(template_path))

        self.gear = gear
        z = gear.z
        m = gear.m
        beta = gear.beta
        alpha = gear.alpha
        x = gear.x
        rho_f = gear.profile.rho_fp
        d_s = gear.shaft_diameter
        c = gear.profile.c
        b = gear.b

        gear_data = {'m_n': m, 'z': z, 'beta': beta, 'alpha_n': alpha, 'x': x, 'rho_f': rho_f, 'd_s': d_s, 'c': c,
                     'b': b}
        self.gear.export_data = GearExport(gear_data)

    def matlab_comsol(self, output_folder='', model_name='model', type='2D'):
        """

        :param model_name:
        :param output_folder:
        :param type:
        """

        if type is '2D':
            template = self.env.get_template('comsol_gear.template')
        elif type is '3D':
            template = self.env.get_template('comsol_gear3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        model_name = model_name.replace(' ', '_')
        output_folder = output_folder.replace('/', '\\')

        output_from_parsed_template = template.render(gear=self.gear.export_data.gear, model_name=model_name,
                                                      model_path=output_folder)

        with open(output_folder + '/' + model_name + '.m', "wb") as fh:
            fh.write(output_from_parsed_template)

    def abaqus(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        :raise ValueError:
        """

        if type is '2D':
            template = self.env.get_template('abaqus_gear.template')
        elif type is '3D':
            template = self.env.get_template('abaqus_gear3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        model_name = model_name.replace(' ', '_')
        output_folder = output_folder.replace('/', '\\')

        output_from_parsed_template = template.render(gear=self.gear.export_data.gear, model_name=model_name,
                                                      model_path=output_folder)

        with open(output_folder + '/' + model_name + '.py', "wb") as fh:
            fh.write(output_from_parsed_template)

    def ansys(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        :raise ValueError:
        """

        if type is '2D':
            template = self.env.get_template('ansys_gear.template')
        elif type is '3D':
            template = self.env.get_template('ansys_gear3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        model_name = model_name.replace(' ', '_')
        output_folder = output_folder.replace('/', '\\')

        final = []
        for i in self.gear.export_data.gear.formcoords:
            final.append([-i[0], i[1]])
        final.reverse()
        self.gear.export_data.gear.formcoords = self.gear.export_data.gear.formcoords + final

        self.gear.export_data.gear.shaftcoords[0] = [-self.gear.export_data.gear.shaftcoords[1][0],
                                                     self.gear.export_data.gear.shaftcoords[1][1]]

        output_from_parsed_template = template.render(gear=self.gear.export_data.gear, model_name=model_name,
                                                      model_path=output_folder)

        with open(output_folder + '/' + model_name + '.js', "wb") as fh:
            fh.write(output_from_parsed_template)


class ExportPair(object):
    """

    :param pair:
    """

    def __init__(self, pair):
        template_path = os.path.join(gearbox.__path__[0], 'export', 'templates')
        self.env = Environment(loader=FileSystemLoader(template_path))

        self.pinion = ExportGear(pair[0]).gear.export_data.gear
        self.wheel = ExportGear(pair[1]).gear.export_data.gear

        shaft = [[0, (self.wheel.data['d_s'] / 2)], rotate([[0, self.wheel.data['d_s'] / 2]], 0.5 * (
            (self.wheel.data['d_s'] / self.wheel.data['z']) * 360 / self.wheel.data['d_s']))[0]]

        coords = rotate(self.wheel.formcoords, 180)

        aw = self.__aw()

        self.wheel.shaftcoords = [[coord[0], coord[1] + aw] for coord in rotate(shaft, 180)]
        self.wheel.formcoords = [[coord[0], coord[1] + aw] for coord in coords]

        self.pinion.rotate_x = 0
        self.pinion.rotate_y = 0

        self.wheel.rotate_x = 0
        self.wheel.rotate_y = aw

    def matlab_comsol(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        """

        if type is '2D':
            template = self.env.get_template('comsol_pair.template')
        elif type is '3D':
            template = self.env.get_template('comsol_pair3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        pair = [self.pinion, self.wheel]

        model_name = model_name.replace(' ', '_')

        output_from_parsed_template = template.render(pair=pair, model_name=model_name, model_path=output_folder)

        with open(output_folder + '/' + model_name + '.m', "wb") as fh:
            fh.write(output_from_parsed_template)

    def abaqus(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        """

        if type is '2D':
            template = self.env.get_template('abaqus_pair.template')
        elif type is '3D':
            template = self.env.get_template('abaqus_pair3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        pair = [self.pinion, self.wheel]

        model_name = model_name.replace(' ', '_')

        output_from_parsed_template = template.render(pair=pair, model_name=model_name, model_path=output_folder)

        with open(output_folder + '/' + model_name + '.py', "wb") as fh:
            fh.write(output_from_parsed_template)

    def ansys(self, output_folder='', model_name='model', type='2D'):
        """

        :param output_folder:
        :param model_name:
        :param type:
        """
        if type is '2D':
            template = self.env.get_template('ansys_pair.template')
        elif type is '3D':
            template = self.env.get_template('ansys_pair3D.template')
        else:
            raise ValueError('type must be \'2D\' or \'3D\' default Value is \'2D\'')

        pinion = []
        for i in self.pinion.formcoords:
            pinion.append([-i[0], i[1]])
        pinion.reverse()
        self.pinion.formcoords = rotate(self.pinion.formcoords + pinion, self.pinion.rotate_ang)
        self.pinion.shaftcoords[0] = [-self.pinion.shaftcoords[1][0], self.pinion.shaftcoords[1][1]]
        self.pinion.shaftcoords = rotate(self.pinion.shaftcoords, self.pinion.rotate_ang)

        wheel = []
        for i in self.wheel.formcoords:
            wheel.append([-i[0], i[1]])
        wheel.reverse()
        self.wheel.formcoords = self.wheel.formcoords + wheel
        self.wheel.shaftcoords[0] = [-self.wheel.shaftcoords[1][0], self.wheel.shaftcoords[1][1]]

        self.wheel.formcoords = rotate(self.wheel.formcoords, self.wheel.rotate_ang, (0, self.__aw()))
        self.wheel.shaftcoords = rotate(self.wheel.shaftcoords, self.wheel.rotate_ang, (0, self.__aw()))

        pair = [self.pinion, self.wheel]
        model_name = model_name.replace(' ', '_')
        output_from_parsed_template = template.render(pair=pair, model_name=model_name, model_path=output_folder)

        with open(output_folder + '/' + model_name + '.js', "wb") as fh:
            fh.write(output_from_parsed_template)


    def __aw(self):
        inv = involute(self.pinion.data['alpha_t']) + 2 * (self.pinion.data['x'] + self.wheel.data['x']) / (
            self.pinion.data['z'] + self.wheel.data['z']) * tan(
            radians(self.pinion.data['alpha_n']))
        alpha_wt = arcinvolute(inv)
        a = ((self.pinion.data['z'] + self.wheel.data['z']) * self.pinion.data['m_n']) / (
            2 * cos(radians(self.pinion.data['beta'])))
        aw = a * cos(radians(self.pinion.data['alpha_n'])) / cos(radians(alpha_wt))
        return aw
